"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var yargs_1 = __importDefault(require("yargs"));
var fs_1 = __importDefault(require("fs"));
var opn_1 = __importDefault(require("opn"));
var path_1 = __importDefault(require("path"));
var BUILDIN_LAYOUTS = [
    "top" /* Top */,
    "top-left" /* TopLeft */,
    "top-right" /* TopRight */,
    "top-left-right-bottom" /* TopLeftRightBottom */,
    "top-bottom-left-right" /* TopBottomLeftRight */,
    "left-top" /* LeftTop */,
    "left-top-bottom" /* LeftTopBottom */
];
function main() {
    yargs_1.default
        .strict()
        .command({
        command: "$0 <layout>",
        describe: 'available layouts',
        handler: handler,
        builder: function (yargs) {
            return yargs.positional('layout', {
                describe: 'layout',
                type: 'string',
                choices: BUILDIN_LAYOUTS.concat('all')
            });
        }
    })
        .options("debug", {
        describe: "enable debug",
        type: "boolean",
        default: false
    })
        .version()
        .alias('v', 'version')
        .help('h')
        .alias('h', 'help')
        .argv;
}
exports.default = main;
function handler(argv) {
    var debug = argv.debug;
    var layout = argv.layout;
    var template = path_1.default.resolve(__dirname, "../afdesign", layout + ".afdesign");
    if (debug) {
        console.log("[ad-bootstrap] Use layout: " + layout);
        console.log("[ad-bootstrap] Template path: " + template);
    }
    if (!fs_1.default.existsSync(template))
        throw new Error("Template not found");
    opn_1.default(template);
}
main();
//# sourceMappingURL=cli.js.map